@@ -571,7 +571,7 @@ DescribeConfigurationRevisionResponseTypeDef = TypedDict(
         "CreationTime": datetime,
         "Description": str,
         "Revision": int,
-        "ServerProperties": StreamingBody,
+        "ServerProperties": bytes,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
